from abc import ABC, abstractmethod


class StreamMachineEvent(ABC):
    @abstractmethod
    def get_strm_schema_id(self) -> str:
        pass

    @abstractmethod
    def get_strm_schema(self):
        pass

    @abstractmethod
    def get_strm_schema_type(self):
        pass



#!/usr/bin/env python

from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

setup(
    author="Stream Machine B.V.",
    author_email='apis@streammachine.io',
    python_requires='>=3.6',
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Topic :: Internet :: WWW/HTTP',
    ],
    description="Common Schema components for Stream Machine driver",
    install_requires=[],
    long_description=readme,
    include_package_data=True,
    keywords='streammachine schema-common client driver',
    name='streammachine-schemas-common',
    packages=find_packages(),
    namespace_packages=['streammachine', 'streammachine.schemas'],
    setup_requires=[],
    version='0.0.1',
    zip_safe=False,
)
